summaryrefslogtreecommitdiffstats
path: root/svx/source/sdr/properties/measureproperties.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/source/sdr/properties/measureproperties.cxx')
-rw-r--r--svx/source/sdr/properties/measureproperties.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/source/sdr/properties/measureproperties.cxx b/svx/source/sdr/properties/measureproperties.cxx
index 8c935c2700f0..522f3e44e686 100644
--- a/svx/source/sdr/properties/measureproperties.cxx
+++ b/svx/source/sdr/properties/measureproperties.cxx
@@ -117,9 +117,9 @@ namespace sdr
GetObjectItemSet();
//#71958# by default, the show units Bool-Item is set as hard
// attribute to TRUE to aviod confusion when copying SdrMeasureObj's
// from one application to another
- mpItemSet->Put(SdrMeasureShowUnitItem(TRUE));
+ mpItemSet->Put(SdrMeasureShowUnitItem(sal_True));
basegfx::B2DPolygon aNewPolygon;
aNewPolygon.append(basegfx::B2DPoint(100.0, 0.0));
@@ -117,9 +117,9 @@ namespace sdr
GetObjectItemSet();
//#71958# by default, the show units Bool-Item is set as hard
- // attribute to TRUE to aviod confusion when copying SdrMeasureObj's
+ // attribute to sal_True to aviod confusion when copying SdrMeasureObj's
// from one application to another